@@ -4,4 +4,7 @@
 # @file:__init__.py.py
 # @software:PyCharm
 
+'''
+    2023.1.12 暂时停止编写 下拉框
+'''
 from PyQtGuiLib.core.comboBox.comboBox import ComboBox
\ No newline at end of file
